package com.clx.performance.listener;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.clx.performance.constant.RabbitKeyConstants;
import com.clx.performance.data.OrderChildData;
import com.clx.performance.enums.OrderChildEnum;
import com.msl.common.utils.DtsMapConvertUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.*;
import org.springframework.stereotype.Component;

import java.util.Objects;

@Slf4j
@Component
public class OrderChildDtsListener  {


    @RabbitListener(queues = RabbitKeyConstants.CLX_PERFORMANCE_ORDER_CHILD_QUEUE)
    public void onMessage(Message message) {
        try {
            String msg = new String(message.getBody());
            log.info("DTS消息同步开始, database:clx_performance.order_child, msg:{}", msg);

            JSONObject object = JSON.parseObject(msg);

            JSONObject beforeMap = object.getJSONObject("beforeMap");
            JSONObject afterMap = object.getJSONObject("afterMap");

            OrderChildData before = DtsMapConvertUtil.convert(beforeMap, new OrderChildData());
            OrderChildData after = DtsMapConvertUtil.convert(afterMap, new OrderChildData());

            if(Objects.isNull(before) && Objects.nonNull(after)){
                //同步after数据
                System.out.println("新增:"+after);
            }else if(Objects.nonNull(before) && Objects.nonNull(after)){
                if(OrderChildEnum.SYNC_STATUS_lIST.contains(after.getStatus()) && !Objects.equals(before.getStatus(),after.getStatus())){
                    //同步after数据
                    System.out.println("修改:"+after);
                }
            }else if(Objects.nonNull(before) && Objects.isNull(after)){
                //数据删除
                System.out.println("删除:"+before);
            }


        } catch (Exception e) {
            log.info("DTS消息同步失败, database:clx_performance.order_child, error:{}", e.getMessage());
        }
    }

}
